@@ -25,7 +25,7 @@ setMethod("parallelSlotNames", "RangedSummarizedExperiment",
 
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### Validity.
+### Validity
 ###
 
 ### The names and mcols of a RangedSummarizedExperiment must be set on its
@@ -52,7 +52,7 @@ setValidity2("RangedSummarizedExperiment", .valid.RangedSummarizedExperiment)
 
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### Constructor.
+### Constructor
 ###
 
 .new_RangedSummarizedExperiment <- function(assays, rowRanges, colData,
@@ -82,13 +82,12 @@ setValidity2("RangedSummarizedExperiment", .valid.RangedSummarizedExperiment)
     rownames(assays[[1L]])
 }
 
-setGeneric("SummarizedExperiment",
-    function(assays, ...) standardGeneric("SummarizedExperiment"))
-
-setMethod("SummarizedExperiment", "SimpleList",
-   function(assays, rowData=NULL, rowRanges=GRangesList(), colData=DataFrame(),
-            metadata=list())
+SummarizedExperiment <- function(assays=SimpleList(),
+                                 rowData=NULL, rowRanges=GRangesList(),
+                                 colData=DataFrame(),
+                                 metadata=list())
 {
+    assays <- normarg_assays(assays)
     if (missing(colData) && 0L != length(assays)) {
         assay <- assays[[1]]
         nms <- colnames(assay)
@@ -99,7 +98,6 @@ setMethod("SummarizedExperiment", "SimpleList",
         if (is.null(rownames(colData)))
             rownames(colData) <- .get_colnames_from_assays(assays)
     }
-    ans_colnames <- rownames(colData)
 
     if (is.null(rowData)) {
         if (missing(rowRanges)) {
@@ -126,32 +124,6 @@ setMethod("SummarizedExperiment", "SimpleList",
         }
     }
 
-    ## validate the assay rownames and colnames
-    .validate_names <- function(nms, expected_nms, what1, what2)
-    {
-        if (is.null(nms))
-            return()
-        if (!is.character(nms))
-            stop(wmsg(what1, " must be NULL or a character vector"))
-        if (!is.null(attributes(nms)))
-            stop(wmsg(what1, " must be NULL or a character vector",
-                             " with no attributes"))
-        if (!identical(nms, expected_nms))
-            stop(wmsg(what1, " must be NULL or identical to ", what2))
-    }
-
-    for(i in seq_along(assays)) {
-        a <- assays[[i]]
-        rownames <- rownames(a)
-        .validate_names(rownames, ans_rownames,
-                        "assay rownames()",
-                        "rowData rownames() / rowRanges names()")
-        colnames <- colnames(a)
-        .validate_names(colnames, ans_colnames,
-                        "assay colnames()",
-                        "colData rownames()")
-    }
-
     assays <- Assays(assays)
 
     if (missing(rowRanges) && !is(rowData, "GenomicRanges_OR_GRangesList")) {
@@ -160,32 +132,11 @@ setMethod("SummarizedExperiment", "SimpleList",
     } else {
         .new_RangedSummarizedExperiment(assays, rowRanges, colData, metadata)
     }
-})
-
-setMethod("SummarizedExperiment", "ANY",
-    function(assays, ...)
-{
-    if (is.matrix(assays) && is.list(assays))
-        ## special case -- matrix of lists
-        assays <- list(assays)
-    SummarizedExperiment(SimpleList(assays), ...)
-})
-
-setMethod("SummarizedExperiment", "list",
-    function(assays, ...)
-{
-    SummarizedExperiment(do.call(SimpleList, assays), ...)
-})
-
-setMethod("SummarizedExperiment", "missing",
-    function(assays, ...)
-{
-    SummarizedExperiment(SimpleList(), ...)
-})
+}
 
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### Coercion.
+### Coercion
 ###
 ### See makeSummarizedExperimentFromExpressionSet.R for coercion back and
 ### forth between SummarizedExperiment and ExpressionSet.
@@ -221,7 +172,7 @@ setAs("SummarizedExperiment", "RangedSummarizedExperiment",
 
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### Getters and setters.
+### Accessors
 ###
 
 ### The rowRanges() generic is defined in the DelayedArray package.
@@ -301,11 +252,10 @@ setReplaceMethod("dimnames", c("RangedSummarizedExperiment", "list"),
 
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### Subsetting.
+### Subsetting
 ###
 
-.DollarNames.RangedSummarizedExperiment <-
-    .DollarNames.SummarizedExperiment
+.DollarNames.RangedSummarizedExperiment <- .DollarNames.SummarizedExperiment
 
 setMethod("subset", "RangedSummarizedExperiment",
     function(x, subset, select, ...)
