@@ -25,7 +25,7 @@ setMethod("parallelSlotNames", "SummarizedExperiment",
 
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### Validity.
+### Validity
 ###
 
 .valid.SummarizedExperiment.assays_nrow <- function(x)
@@ -73,7 +73,7 @@ setValidity2("SummarizedExperiment", .valid.SummarizedExperiment)
 
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### Low-level constructor (not exported).
+### Low-level constructor (not exported)
 ###
 
 new_SummarizedExperiment <- function(assays, names, rowData, colData,
@@ -99,7 +99,7 @@ new_SummarizedExperiment <- function(assays, names, rowData, colData,
 
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### Getters and setters.
+### Accessors
 ###
 
 setMethod("length", "SummarizedExperiment",
@@ -111,7 +111,7 @@ setMethod("names", "SummarizedExperiment", function(x) x@NAMES)
 setReplaceMethod("names", "SummarizedExperiment",
     function(x, value)
     {
-        NAMES <- S4Vectors:::normalize_names_replacement_value(value, x)
+        NAMES <- S4Vectors:::normarg_names(value, class(x), length(x))
         BiocGenerics:::replaceSlots(x, NAMES=NAMES, check=FALSE)
     }
 )
@@ -150,6 +150,13 @@ setReplaceMethod("colData", c("SummarizedExperiment", "DataFrame"),
     BiocGenerics:::replaceSlots(x, colData=value, check=FALSE)
 })
 
+setReplaceMethod("colData", c("SummarizedExperiment", "NULL"),
+    function(x, ..., value)
+{
+    value <- new2("DFrame", nrows=ncol(x), rownames=colnames(x), check=FALSE)
+    BiocGenerics:::replaceSlots(x, colData=value, check=FALSE)
+})
+
 setGeneric("assays",
     function(x, ..., withDimnames=TRUE) standardGeneric("assays"),
     signature="x")
@@ -177,17 +184,10 @@ setGeneric("assays<-",
     function(x, ..., withDimnames=TRUE, value)
 {
     ## withDimnames arg allows names(assays(se, withDimnames=FALSE)) <- value
-    ok <- vapply(value, function(elt, xdimnames) {
-        e <- dimnames(elt)
-        (is.null(e[[1]]) || identical(e[[1]], xdimnames[[1]])) &&
-             (is.null(e[[2]]) || identical(e[[2]], xdimnames[[2]]))
-    }, logical(1), xdimnames=dimnames(x))
-    if (!all(ok))
-        stop("current and replacement dimnames() differ")
     x <- BiocGenerics:::replaceSlots(x, assays=Assays(value), check=FALSE)
-    ## validObject(x) should be called below because it would then fully
-    ## re-validate objects that derive from SummarizedExperiment (e.g.
-    ## DESeqDataSet objects) after the user sets the assays slot with
+    ## validObject(x) should NOT be called below because it would then
+    ## fully re-validate objects that derive from SummarizedExperiment
+    ## (e.g. DESeqDataSet objects) after the user sets the assays slot with
     ## assays(x) <- value. For example the assays slot of a DESeqDataSet
     ## object must contain a matrix named 'counts' and calling validObject(x)
     ## would check that but .valid.SummarizedExperiment(x) doesn't.
@@ -290,11 +290,7 @@ setReplaceMethod("assayNames", c("SummarizedExperiment", "character"),
     x
 })
 
-## cannonical location for dim, dimnames; dimnames should be checked
-## for consistency (if non-null) and stripped from assays on
-## construction, or added from assays if row/col names are NULL in
-## <SummarizedExperiment> but not assays. dimnames need to be added on
-## to assays when assays() invoked
+## cannonical location for dim, dimnames
 setMethod("dim", "SummarizedExperiment",
     function(x)
 {
@@ -310,9 +306,9 @@ setMethod("dimnames", "SummarizedExperiment",
 setReplaceMethod("dimnames", c("SummarizedExperiment", "list"),
     function(x, value)
 {
-    NAMES <- S4Vectors:::normalize_names_replacement_value(value[[1]], x)
+    NAMES <- S4Vectors:::normarg_names(value[[1L]], class(x), length(x))
     colData <- colData(x)
-    rownames(colData) <- value[[2]]
+    rownames(colData) <- value[[2L]]
     BiocGenerics:::replaceSlots(x, NAMES=NAMES, colData=colData, check=FALSE)
 })
 
@@ -325,7 +321,7 @@ setReplaceMethod("dimnames", c("SummarizedExperiment", "NULL"),
 
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### Subsetting.
+### Subsetting
 ###
 
 .SummarizedExperiment.charbound <-
@@ -552,8 +548,9 @@ setMethod("subset", "SummarizedExperiment",
     x[i, j]
 })
 
+
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### Quick colData access.
+### Quick colData access
 ###
 
 setMethod("[[", c("SummarizedExperiment", "ANY", "missing"),
@@ -587,21 +584,12 @@ setReplaceMethod("$", "SummarizedExperiment",
 
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### Display.
+### Show
 ###
 
 setMethod("show", "SummarizedExperiment",
     function(object)
 {
-    selectSome <- S4Vectors:::selectSome
-    scat <- function(fmt, vals=character(), exdent=2, ...)
-    {
-        vals <- ifelse(nzchar(vals), vals, "''")
-        lbls <- paste(S4Vectors:::selectSome(vals), collapse=" ")
-        txt <- sprintf(fmt, length(vals), lbls)
-        cat(strwrap(txt, exdent=exdent, ...), sep="\n")
-    }
-
     cat("class:", class(object), "\n")
     cat("dim:", dim(object), "\n")
 
@@ -609,34 +597,34 @@ setMethod("show", "SummarizedExperiment",
     expt <- names(metadata(object))
     if (is.null(expt))
         expt <- character(length(metadata(object)))
-    scat("metadata(%d): %s\n", expt)
+    coolcat("metadata(%d): %s\n", expt)
 
     ## assays()
     nms <- assayNames(object)
     if (is.null(nms))
         nms <- character(length(assays(object, withDimnames=FALSE)))
-    scat("assays(%d): %s\n", nms)
+    coolcat("assays(%d): %s\n", nms)
 
     ## rownames()
     dimnames <- dimnames(object)
     dlen <- sapply(dimnames, length)
-    if (dlen[[1]]) scat("rownames(%d): %s\n", dimnames[[1]])
-    else scat("rownames: NULL\n")
+    if (dlen[[1]]) coolcat("rownames(%d): %s\n", dimnames[[1]])
+    else cat("rownames: NULL\n")
 
     ## rowData`()
-    scat("rowData names(%d): %s\n", names(rowData(object, use.names=FALSE)))
+    coolcat("rowData names(%d): %s\n", names(rowData(object, use.names=FALSE)))
 
     ## colnames()
-    if (dlen[[2]]) scat("colnames(%d): %s\n", dimnames[[2]])
+    if (dlen[[2]]) coolcat("colnames(%d): %s\n", dimnames[[2]])
     else cat("colnames: NULL\n")
 
     ## colData()
-    scat("colData names(%d): %s\n", names(colData(object)))
+    coolcat("colData names(%d): %s\n", names(colData(object)))
 })
 
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### Combine.
+### Combine
 ###
 
 ### Appropriate for objects with different ranges and same samples.
@@ -859,7 +847,8 @@ setMethod("realize", "SummarizedExperiment",
 .updateObject_SummarizedExperiment <- function(object, ..., verbose=FALSE)
 {
     object@assays <- updateObject(object@assays, ..., verbose=verbose)
-    object
+    object@colData <- updateObject(object@colData, ..., verbose=verbose)
+    callNextMethod()  # call method for Vector objects
 }
 
 setMethod("updateObject", "SummarizedExperiment",
